======================================
 Welcome to pylibacl's documentation!
======================================

See the :doc:`README <readme>` for start, or the detailed :doc:`module
<module>` information.

Contents
--------

.. toctree::
   :maxdepth: 2

   readme.md
   contributing.md
   security.md
   module.rst
   implementation.rst
   news.md

Also see the :ref:`search`.
